<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        // centros de trabajo o estaciones de producción
        Schema::create('store_work_centers', function (Blueprint $table) {
            $table->smallIncrements('id');

            $table->unsignedSmallInteger('store_id')->index();

            $table->string('code', 16)->nullable()->unique()->comment('Código único del centro de trabajo');
            $table->string('name', 96)->index(); // Nombre del centro de trabajo
            $table->mediumText('description')->nullable(); // Descripción del centro

            $table->unsignedMediumInteger('manager_id')->nullable()->index(); // sat_codigo_postal.

            $table->string('tel')->nullable();
            $table->string('tel2')->nullable();

            $table->decimal('lat', 9, 6)->nullable()->comment('Latitud de la ubicación del centros de trabajo');
            $table->decimal('lng', 9, 6)->nullable()->comment('Longitud de la ubicación del centros de trabajo');

            $table->unsignedTinyInteger('status')->index(); // 'active', 'inactive'

            $table->timestamps();

            // Indices
            $table->unique(['store_id', 'name']);

            // Relaciones
            $table->foreign('store_id')->references('id')->on('stores')->onDelete('restrict');
            $table->foreign('manager_id')->references('id')->on('users')->onUpdate('restrict')->onDelete('restrict');
        });

    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('store_work_centers');

    }
};
