<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('currencies', function (Blueprint $table) {
            $table->smallIncrements('id');

            $table->char('c_currency', 3)->charset('ascii')->collation('ascii_general_ci')->unique();
            $table->string('symbol', 10)->nullable();

            $table->boolean('auto_update_exchange_rates')->default(true);
            $table->unsignedInteger('refresh_interval')->default(24); // Tiempo de actualización en horas
            $table->decimal('adjustment_percent', 5, 2)->default(0); // Ajuste porcentual opcional

            $table->boolean('status');

            // Auditoria
            $table->timestamps();

            // Relaciones
            $table->foreign('c_currency')->references('c_moneda')->on('sat_moneda')->onUpdate('restrict')->onDelete('restrict');
        });

        Schema::create('currency_exchange_rates', function (Blueprint $table) {
            $table->id();
            $table->char('c_currency', 3)->charset('ascii')->collation('ascii_general_ci');
            $table->decimal('exchange_rate', 10, 4);
            $table->date('exchange_date'); // Se almacena la fecha de la tasa de cambio
            $table->string('source'); // Fuente (banxico, fixer, etc.)
            $table->unsignedMediumInteger('updated_by')->nullable(); // Usuario que hizo el cambio
            $table->text('comments')->nullable(); // Comentarios sobre la modificación

            // Auditori
            $table->timestamps();

            // Indicies
            $table->unique(['c_currency', 'exchange_date', 'source']); // Evita duplicados
            $table->index(['c_currency', 'exchange_date']);

            // Llaves foráneas
            $table->foreign('c_currency')->references('c_currency')->on('currencies')->onDelete('cascade');
            $table->foreign('updated_by')->references('id')->on('users')->onDelete('set null'); // Relación con usuarios
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists(['currencies', 'currency_exchange_rates']);

    }
};
